@@ -14,7 +14,7 @@ class Package(BaseModel):
 
     Message: Optional[Message]
     PackageWeight: PackageWeight
-    ReferenceNumber: ReferenceNumber
+    ReferenceNumber: Optional[ReferenceNumber]
     
     @property
     def get_US_activities(self) -> List[ActivityItem]:
@@ -22,4 +22,11 @@ class Package(BaseModel):
         for activity in self.AllActivity:
             if activity.ActivityLocation is not None and activity.ActivityLocation.Address is not None and activity.ActivityLocation.Address.CountryCode == "US":
                 activities.append(activity)
-        return activities
\ No newline at end of file
+        return activities
+    
+    @property
+    def is_delivered(self) -> bool:
+        if "Delivered" in self.AllActivity[0].description:
+            return True
+        return False
+    
\ No newline at end of file
