@@ -12,7 +12,7 @@ from UPS_SDK.models.ShipmentWeight import ShipmentWeight
 class Shipment(BaseModel):
     Shipper: Shipper
     ShipTo: ShipTo
-    ShipmentWeight: ShipmentWeight
+    ShipmentWeight: Optional[ShipmentWeight]
     Service: Service
     ReferenceNumbers: Optional[List[ReferenceNumberItem]] = Field(None, alias="ReferenceNumber")
     ShipmentIdentificationNumber: str
@@ -22,6 +22,12 @@ class Shipment(BaseModel):
     
     @property
     def scheduled_delivery_date(self):
+        date = None
         if self.Package.RescheduledDeliveryDate is not None:
-            return datetime.strptime(self.Package.RescheduledDeliveryDate, "%Y%m%d")
-        return datetime.strptime(self.ScheduledDeliveryDate, "%Y%m%d")
\ No newline at end of file
+            date = datetime.strptime(self.Package.RescheduledDeliveryDate, "%Y%m%d")
+            
+        elif self.ScheduledDeliveryDate is not None:
+            date = datetime.strptime(self.ScheduledDeliveryDate, "%Y%m%d")
+            
+        return date
+        
\ No newline at end of file
